@@ -182,11 +182,23 @@ public:
     mutable bool m_useIconNameCache : 1;
 
     // Auto: check leading dot.
-    enum { Auto, Hidden, Shown } m_hidden : 3;
-    mutable enum { HiddenUncached, HiddenCached, ShownCached } m_hiddenCache : 3;
+    enum {
+        Auto,
+        Hidden,
+        Shown
+    } m_hidden : 3;
+    mutable enum {
+        HiddenUncached,
+        HiddenCached,
+        ShownCached
+    } m_hiddenCache : 3;
 
     // Slow? (nfs/smb/ssh)
-    mutable enum { SlowUnknown, Fast, Slow } m_slow : 3;
+    mutable enum {
+        SlowUnknown,
+        Fast,
+        Slow
+    } m_slow : 3;
 
     /**
      * True if MIME type determination by content should be skipped
@@ -725,6 +737,10 @@ QString KFileItem::linkDest() const
 
     d->ensureInitialized();
 
+    if (!d->m_bLink) {
+        return QString{};
+    }
+
     // Extract it from the KIO::UDSEntry
     const QString linkStr = d->m_entry.stringValue(KIO::UDSEntry::UDS_LINK_DEST);
     if (!linkStr.isEmpty()) {
@@ -737,20 +753,15 @@ QString KFileItem::linkDest() const
 #ifdef Q_OS_UNIX
         // Use readlink on Unix because symLinkTarget turns relative targets into absolute (#456198)
         // implementation following file_unix.cpp readlinkToBuffer()
-#if HAVE_STATX
-        using SizeType = size_t;
-#else
-        using SizeType = off_t;
-#endif
-        SizeType linkSize = size();
+        size_t linkSize = size();
         const QString path = d->m_url.adjusted(QUrl::StripTrailingSlash).toLocalFile();
         if (linkSize > SIZE_MAX) {
             qCWarning(KIO_CORE) << "file size bigger than SIZE_MAX, too big for readlink use!" << path;
             return {};
         }
-        SizeType lowerBound = 256;
-        SizeType higherBound = 1024;
-        SizeType bufferSize = qBound(lowerBound, linkSize + 1, higherBound);
+        size_t lowerBound = 256;
+        size_t higherBound = 1024;
+        size_t bufferSize = qBound(lowerBound, linkSize + 1, higherBound);
         QByteArray linkTargetBuffer(bufferSize, Qt::Initialization::Uninitialized);
         const QByteArray pathBA = QFile::encodeName(path);
         while (true) {
@@ -758,7 +769,7 @@ QString KFileItem::linkDest() const
             if (n < 0 && errno != ERANGE) {
                 qCWarning(KIO_CORE) << "readlink failed!" << pathBA;
                 return {};
-            } else if (n > 0 && static_cast<SizeType>(n) != bufferSize) {
+            } else if (n > 0 && static_cast<size_t>(n) != bufferSize) {
                 // the buffer was not filled in the last iteration
                 // we are finished reading, break the loop
                 linkTargetBuffer.truncate(n);
