@@ -14,7 +14,7 @@
 #include "standardthumbnailjob_p.h"
 #include "statjob.h"
 
-#if defined(Q_OS_UNIX) && !defined(Q_OS_ANDROID)
+#if defined(Q_OS_UNIX) && !defined(Q_OS_ANDROID) && !defined(Q_OS_HAIKU)
 #define WITH_SHM 1
 #else
 #define WITH_SHM 0
@@ -830,6 +830,10 @@ QDir KIO::PreviewJobPrivate::createTemporaryDir()
 void PreviewJobPrivate::createThumbnail(const QString &pixPath)
 {
     Q_Q(PreviewJob);
+
+    QFileInfo info(pixPath);
+    Q_ASSERT_X(info.isAbsolute(), "PreviewJobPrivate::createThumbnail", qPrintable(QLatin1String("path is not absolute: ") + info.path()));
+
     state = PreviewJobPrivate::STATE_CREATETHUMB;
 
     bool save = bSave && currentItem.plugin.value(QStringLiteral("CacheThumbnail"), true) && !sequenceIndex;
