@@ -8,9 +8,11 @@
 #ifndef KFILEITEMDELEGATE_H
 #define KFILEITEMDELEGATE_H
 
+#include "kiowidgets_export.h"
 #include <QAbstractItemDelegate>
 #include <QTextOption>
-#include "kiowidgets_export.h"
+
+#include <memory>
 
 class QAbstractItemModel;
 class QAbstractItemView;
@@ -116,7 +118,6 @@ class KIOWIDGETS_EXPORT KFileItemDelegate : public QAbstractItemDelegate
     /**
      * This property determines if there are KIO jobs on a destination URL visible, then
      * they will have a small animation overlay displayed on them.
-     * @since 4.5
      */
     Q_PROPERTY(bool jobTransfersVisible READ jobTransfersVisible WRITE setJobTransfersVisible)
 
@@ -143,20 +144,20 @@ public:
      * @see information
      */
     enum Information {
-        NoInformation,     ///< No additional information will be shown for items.
-        Size,              ///< The file size for files, and the number of items for folders.
-        Permissions,       ///< A UNIX permissions string, e.g. -rwxr-xr-x.
-        OctalPermissions,  ///< The permissions as an octal value, e.g. 0644.
-        Owner,             ///< The user name of the file owner, e.g. root
-        OwnerAndGroup,     ///< The user and group that owns the file, e.g. root:root
-        CreationTime,      ///< The date and time the file/folder was created.
-        ModificationTime,  ///< The date and time the file/folder was last modified.
-        AccessTime,        ///< The date and time the file/folder was last accessed.
-        MimeType,          ///< The MIME type for the item, e.g. text/html.
-        FriendlyMimeType,  ///< The descriptive name for the MIME type, e.g. HTML Document.
-        LinkDest,          ///< The destination of a symbolic link. @since 4.5
-        LocalPathOrUrl,    ///< The local path to the file or the URL in case it is not a local file. @since 4.5
-        Comment            ///< A simple comment that can be displayed to the user as is. @since 4.6
+        NoInformation, ///< No additional information will be shown for items.
+        Size, ///< The file size for files, and the number of items for folders.
+        Permissions, ///< A UNIX permissions string, e.g.\ -rwxr-xr-x.
+        OctalPermissions, ///< The permissions as an octal value, e.g.\ 0644.
+        Owner, ///< The user name of the file owner, e.g.\ root
+        OwnerAndGroup, ///< The user and group that owns the file, e.g.\ root:root
+        CreationTime, ///< The date and time the file/folder was created.
+        ModificationTime, ///< The date and time the file/folder was last modified.
+        AccessTime, ///< The date and time the file/folder was last accessed.
+        MimeType, ///< The MIME type for the item, e.g.\ text/html.
+        FriendlyMimeType, ///< The descriptive name for the MIME type, e.g.\ HTML Document.
+        LinkDest, ///< The destination of a symbolic link. @since 4.5
+        LocalPathOrUrl, ///< The local path to the file or the URL in case it is not a local file. @since 4.5
+        Comment, ///< A simple comment that can be displayed to the user as is. @since 4.6
     };
     Q_ENUM(Information)
 
@@ -172,13 +173,13 @@ public:
     /**
      * Destroys the item delegate.
      */
-    virtual ~KFileItemDelegate();
+    ~KFileItemDelegate() override;
 
     /**
      * Returns the nominal size for the item referred to by @p index, given the
      * provided options.
      *
-     * If the model provides a valid Qt::FontRole and/or Qt::AlignmentRole for the item,
+     * If the model provides a valid Qt::FontRole and/or Qt::TextAlignmentRole for the item,
      * those will be used instead of the ones specified in the style options.
      *
      * This function is reimplemented from @ref QAbstractItemDelegate.
@@ -198,10 +199,10 @@ public:
      * This function will use the following data values if the model provides
      * them for the item, in place of the values in @p option:
      *
-     * @li Qt::FontRole        The font that should be used for the display role.
-     * @li Qt::AlignmentRole   The alignment of the display role.
-     * @li Qt::ForegroundRole  The text color for the display role.
-     * @li Qt::BackgroundRole  The background color for the item.
+     * @li Qt::FontRole           The font that should be used for the display role.
+     * @li Qt::TextAlignmentRole  The alignment of the display role.
+     * @li Qt::ForegroundRole     The text color for the display role.
+     * @li Qt::BackgroundRole     The background color for the item.
      *
      * This function is reimplemented from @ref QAbstractItemDelegate.
      *
@@ -318,7 +319,6 @@ public:
      * Sets the maximum size for KFileItemDelegate::sizeHint().
      *
      * @see maximumSize()
-     * @since 4.1
      */
     void setMaximumSize(const QSize &size);
 
@@ -326,7 +326,6 @@ public:
      * Returns the maximum size for KFileItemDelegate::sizeHint().
      *
      * @see setMaximumSize()
-     * @since 4.1
      */
     QSize maximumSize() const;
 
@@ -338,7 +337,6 @@ public:
      *       from Qt::DisplayRole, or if they match, showToolTipWhenElided
      *       flag is set and the display role information is elided.
      * @see showToolTipWhenElided()
-     * @since 4.2
      */
     void setShowToolTipWhenElided(bool showToolTip);
 
@@ -350,14 +348,12 @@ public:
      *       from Qt::DisplayRole, or if they match, showToolTipWhenElided
      *       flag is set and the display role information is elided.
      * @see setShowToolTipWhenElided()
-     * @since 4.2
      */
     bool showToolTipWhenElided() const;
 
     /**
      * Returns the rectangle of the icon that is aligned inside the decoration
      * rectangle.
-     * @since 4.4
      */
     QRect iconRect(const QStyleOptionViewItem &option, const QModelIndex &index) const;
 
@@ -365,7 +361,6 @@ public:
      * When the contents text needs to be wrapped, @p wrapMode strategy
      * will be followed.
      *
-     * @since 4.4
      */
     void setWrapMode(QTextOption::WrapMode wrapMode);
 
@@ -373,7 +368,6 @@ public:
      * Returns the wrapping strategy followed to show text when it needs
      * wrapping.
      *
-     * @since 4.4
      */
     QTextOption::WrapMode wrapMode() const;
 
@@ -390,15 +384,12 @@ public:
      *
      * Note: The model (KDirModel) needs to have it's method called with the same
      * value, when you make the call to this method.
-     *
-     * @since 4.5
      */
     void setJobTransfersVisible(bool jobTransfersVisible);
 
     /**
      * Returns whether or not the displaying of job transfers is enabled.
      * @see setJobTransfersVisible()
-     * @since 4.5
      */
     bool jobTransfersVisible() const;
 
@@ -421,9 +412,8 @@ public Q_SLOTS:
 
 private:
     class Private;
-    Private *const d;  /// @internal
+    std::unique_ptr<Private> const d; /// @internal
     Q_DISABLE_COPY(KFileItemDelegate)
 };
 
 #endif // KFILEITEMDELEGATE_H
-
